jactorch.parallel.replication\_callback
=======================================

.. automodule:: jactorch.parallel.replication_callback

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      CallbackContext
      ReplicationCallbackDataParallel
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      exec_data_parallel_replication_callback
      patch_replication_callback
   
   

   
   
   








.. rubric:: Class CallbackContext
.. autoclass:: CallbackContext
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ReplicationCallbackDataParallel
.. autoclass:: ReplicationCallbackDataParallel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: exec_data_parallel_replication_callback

.. autofunction:: patch_replication_callback


